@@ -26,7 +26,7 @@ def auto(
     project_name: Optional[str] = None,
     run_name: Optional[str] = None,
     wait: bool = True,
-    create_data_embs: bool = False,
+    create_data_embs: Optional[bool] = None,
 ) -> None:
     """Automatically gets insights on a text classification or NER dataset
 
@@ -92,7 +92,8 @@ def auto(
         and uploaded with this run. You can access these embeddings via
         `dq.metrics.get_data_embeddings` in the `emb` column or
         `dq.metrics.get_dataframe(..., include_data_embs=True)` in the `data_emb` col
-        Only available for TC currently. NER coming soon. Default False.
+        Only available for TC currently. NER coming soon. Default True if a GPU is
+        available, else default False.
 
     For text classification datasets, the only required columns are `text` and `label`
 
@@ -102,6 +103,8 @@ def auto(
 
         MIT Movies dataset in huggingface format
 
+    .. code-block:: python
+
         tokens	                                            ner_tags
         [what, is, a, good, action, movie, that, is, r...	[0, 0, 0, 0, 7, 0, ...
         [show, me, political, drama, movies, with, jef...	[0, 0, 7, 8, 0, 0, ...
@@ -112,28 +115,36 @@ def auto(
 
 
     To see auto insights on a random, pre-selected dataset, simply run
-    ```python
+
+    .. code-block:: python
+
         import dataquality as dq
 
         dq.auto()
-    ```
+
 
     An example using `auto` with a hosted huggingface text classification dataset
-    ```python
+
+    .. code-block:: python
+
         import dataquality as dq
 
         dq.auto(hf_data="rungalileo/trec6")
-    ```
+
 
     Similarly, for NER
-    ```python
+
+    .. code-block:: python
+
         import dataquality as dq
 
         dq.auto(hf_data="conll2003")
-    ```
+
 
     An example using `auto` with sklearn data as pandas dataframes
-    ```python
+
+    .. code-block:: python
+
         import dataquality as dq
         import pandas as pd
         from sklearn.datasets import fetch_20newsgroups
@@ -156,19 +167,20 @@ def auto(
              project_name="newsgroups_work",
              run_name="run_1_raw_data"
         )
-    ```
+
 
     An example of using `auto` with a local CSV file with `text` and `label` columns
-    ```python
-    import dataquality as dq
 
-    dq.auto(
-         train_data="train.csv",
-         test_data="test.csv",
-         project_name="data_from_local",
-         run_name="run_1_raw_data"
-    )
-    ```
+    .. code-block:: python
+
+        import dataquality as dq
+
+        dq.auto(
+            train_data="train.csv",
+            test_data="test.csv",
+            project_name="data_from_local",
+            run_name="run_1_raw_data"
+        )
     """
     # Remove all output from transformers and torch except the progress bar
     set_global_logging_level(logging.ERROR, ["torch"])
